- name
Character. Taxonomic scientific name (e.g. "Aves").
As defined by taxadb::filter_rank().
- rank
Character. Taxonomic rank name. (e.g. "class").
As defined by taxadb::filter_rank().
- provider
Character. From which provider should the hierarchy be returned?
Default is 'gbif', which can also be configured using options(default_taxadb_provide = ...").
See taxadb::td_create() for a list of recognized providers. NOTE: gbif seems to have the most-complete
columns, especially in terms of scientificNameAuthorship, which is important for matching
ambiguous names.
As defined by taxadb::filter_rank().
- version
Character. Which version of the taxadb provider database should we use? defaults
to latest. See tl_import for details. Default = 22.12.
As defined by taxadb::filter_rank().
- collect
Logical. Should we return an in-memory data.frame
(default, usually the most convenient), or a reference to lazy-eval table on disk
(useful for very large tables on which we may first perform subsequent filtering operations.).
Default = TRUE.
As defined by taxadb::filter_rank().
- ignore_case
Logical. should we ignore case (capitalization) in matching names?
Can be significantly slower to run. Default = TRUE.
As defined by taxadb::filter_rank().
- db
a connection to the taxadb database. See details of taxadb::filter_rank(). Default
= Null which should work.
As defined by taxadb::filter_rank().
- removeEmptyNames
Logical. If True (default), it will remove entries without an entry
for specificEpithet.
- outPath
Character. The path to a directory (folder) in which the output should be saved.
- fileName
Character. The name of the output file, ending in '.csv'.
- ...
Arguments passed to taxadb::td_create().